@@ -1,4 +1,7 @@
-__version__ = "0.5.4"
+__version__ = "0.8.1"
+
+# keynet_core를 import하여 민감정보 자동 마스킹 활성화
+import keynet_core  # noqa: F401
 
 from .function import keynet_function
 from .function.decorator import UserInput
