@@ -136,7 +136,7 @@ def main(args):
             """
 from keynet_inference.function import keynet_function
 
-@keynet_function("hello-world")
+@keynet_function("hello-world", description="Test hello-world")
 def main(args):
     name = args.get('name', 'World')
     return {"message": f"Hello {name}!"}
